@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -26,8 +26,8 @@
 #if !defined (__A68G_NIL_H__)
 #define __A68G_NIL_H__
 
-#define NO_A68_REF ((A68_REF *) NULL)
-#define NO_ARRAY ((A68_ARRAY *) NULL)
+#define NO_A68G_REF ((A68G_REF *) NULL)
+#define NO_ARRAY ((A68G_ARRAY *) NULL)
 #define NO_BOOK ((BOOK_T *) NULL)
 #define NO_BOOL ((BOOL_T *) NULL)
 #define NO_BYTE ((BYTE_T *) NULL)
@@ -36,10 +36,10 @@
 #define NO_DIAGNOSTIC ((DIAGNOSTIC_T *) NULL)
 #define NO_EDLIN ((EDLIN_T *) NULL)
 #define NO_FILE ((FILE *) NULL)
-#define NO_FORMAT ((A68_FORMAT *) NULL)
+#define NO_FORMAT ((A68G_FORMAT *) NULL)
 #define NO_GINFO ((GINFO_T *) NULL)
 #define NO_GPROC ((void (*) (NODE_T *)) NULL)
-#define NO_HANDLE ((A68_HANDLE *) NULL)
+#define NO_HANDLE ((A68G_HANDLE *) NULL)
 #define NO_INT ((int *) NULL)
 #define NO_JMP_BUF ((jmp_buf *) NULL)
 #define NO_KEYWORD ((KEYWORD_T *) NULL)
@@ -49,38 +49,18 @@
 #define NO_PACK ((PACK_T *) NULL)
 #define NO_POSTULATE ((POSTULATE_T *) NULL)
 #define NO_PPROC ((PROP_T (*) (NODE_T *)) NULL)
-#define NO_PROCEDURE ((A68_PROCEDURE *) NULL)
+#define NO_PROCEDURE ((A68G_PROCEDURE *) NULL)
 #define NO_REAL ((REAL_T *) NULL)
 #define NO_REFINEMENT ((REFINEMENT_T *) NULL)
 #define NO_REGMATCH ((regmatch_t *) NULL)
 #define NO_SCOPE ((SCOPE_T *) NULL)
 #define NO_SOID ((SOID_T *) NULL)
-#define NO_SOUND ((A68_SOUND *) NULL)
+#define NO_SOUND ((A68G_SOUND *) NULL)
 #define NO_STREAM NO_FILE
 #define NO_TEXT ((char *) NULL)
 #define NO_TICK ((BOOL_T *) NULL)
 #define NO_TOKEN ((TOKEN_T *) NULL)
-#define NO_TUPLE ((A68_TUPLE *) NULL)
-#define NO_VAR (NULL)
-
-static const A68_FORMAT nil_format = {
-  INIT_MASK, NULL, 0
-};
-
-static const A68_HANDLE nil_handle = {
-  INIT_MASK,
-  NO_BYTE,
-  0,
-  NO_MOID,
-  NO_HANDLE,
-  NO_HANDLE
-};
-
-static const A68_REF nil_ref = {
-  (STATUS_MASK_T) (INIT_MASK | NIL_MASK),
-  0,
-  0,
-  NO_HANDLE
-};
+#define NO_TUPLE ((A68G_TUPLE *) NULL)
+#define NO_REF (NULL)
 
 #endif
